#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-graphene
version:                1.0.8
visibility:             public
id:                     gi-graphene-1.0.8-Xk0awpx0vD3LH15Gzl6Cr
key:                    gi-graphene-1.0.8-Xk0awpx0vD3LH15Gzl6Cr
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Graphene bindings
description:            Bindings for Graphene, autogenerated by haskell-gi.
category:               Bindings
abi:                    b9858066061bf2392d7f93f191a73942
exposed:                True
exposed-modules:
    GI.Graphene GI.Graphene.Config GI.Graphene.Constants
    GI.Graphene.Enums GI.Graphene.Structs GI.Graphene.Structs.Box
    GI.Graphene.Structs.Euler GI.Graphene.Structs.Frustum
    GI.Graphene.Structs.Matrix GI.Graphene.Structs.Plane
    GI.Graphene.Structs.Point GI.Graphene.Structs.Point3D
    GI.Graphene.Structs.Quad GI.Graphene.Structs.Quaternion
    GI.Graphene.Structs.Ray GI.Graphene.Structs.Rect
    GI.Graphene.Structs.Simd4F GI.Graphene.Structs.Simd4X4F
    GI.Graphene.Structs.Size GI.Graphene.Structs.Sphere
    GI.Graphene.Structs.Triangle GI.Graphene.Structs.Vec2
    GI.Graphene.Structs.Vec3 GI.Graphene.Structs.Vec4

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-graphene-1.0.8
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-graphene-1.0.8 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-graphene-1.0.8 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-graphene
hs-libraries:           HSgi-graphene-1.0.8-Xk0awpx0vD3LH15Gzl6Cr
extra-libraries:        graphene-1.0 gobject-2.0 glib-2.0
extra-libraries-static:
    graphene-1.0 m gobject-2.0 glib-2.0 atomic m sysprof-capture-4
    pcre2-8 pthread ffi

include-dirs:
    /usr/include/graphene-1.0 /usr/lib/graphene-1.0/include
    /usr/include /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-glib-2.0.30-FejhVcYM7fID8sxSnazhRe
    gi-gobject-2.0.31-BmSKunruCgzyGlfjkMWF9
    haskell-gi-0.26.17-3KJumM1XU8AkHOk3X5Pcn
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-graphene/html/gi-graphene.haddock
haddock-html:           /usr/share/doc/haskell-gi-graphene/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

